summaryrefslogtreecommitdiff
path: root/src/include
diff options
context:
space:
mode:
authorChristian Grothoff <christian@grothoff.org>2017-03-18 22:20:48 +0100
committerChristian Grothoff <christian@grothoff.org>2017-03-18 22:20:48 +0100
commit69ac028a13497d9fa0b7ebf5e3c7992a492aab13 (patch)
tree9180ab195428d2048c2ae1ffe61ada32dd18d431 /src/include
parenta9f9161c3afbebb09fff25a0ce54e27fd6ae1ff9 (diff)
downloadexchange-69ac028a13497d9fa0b7ebf5e3c7992a492aab13.tar.gz
exchange-69ac028a13497d9fa0b7ebf5e3c7992a492aab13.tar.bz2
exchange-69ac028a13497d9fa0b7ebf5e3c7992a492aab13.zip
add required separate risk balance per denomination to auditordb
Diffstat (limited to 'src/include')
-rw-r--r--src/include/taler_auditordb_plugin.h19
1 files changed, 12 insertions, 7 deletions
diff --git a/src/include/taler_auditordb_plugin.h b/src/include/taler_auditordb_plugin.h
index 1a29e5ae5..54e6c5203 100644
--- a/src/include/taler_auditordb_plugin.h
+++ b/src/include/taler_auditordb_plugin.h
@@ -522,15 +522,16 @@ struct TALER_AUDITORDB_Plugin
* @param cls the @e cls of this struct with the plugin-specific state
* @param session connection to use
* @param denom_pub_hash hash of the denomination public key
* @param denom_balance value of coins outstanding (or issued?) with this denomination key
* @return #GNUNET_OK on success; #GNUNET_SYSERR on failure
*/
int
(*insert_denomination_balance)(void *cls,
struct TALER_AUDITORDB_Session *session,
const struct GNUNET_HashCode *denom_pub_hash,
- const struct TALER_Amount *denom_balance);
-
+ const struct TALER_Amount *denom_balance,
+ const struct TALER_Amount *denom_risk);
/**
@@ -540,14 +541,16 @@ struct TALER_AUDITORDB_Plugin
* @param cls the @e cls of this struct with the plugin-specific state
* @param session connection to use
* @param denom_pub_hash hash of the denomination public key
* @param denom_balance value of coins outstanding (or issued?) with this denomination key
* @return #GNUNET_OK on success; #GNUNET_SYSERR on failure
*/
int
(*update_denomination_balance)(void *cls,
struct TALER_AUDITORDB_Session *session,
const struct GNUNET_HashCode *denom_pub_hash,
- const struct TALER_Amount *denom_balance);
+ const struct TALER_Amount *denom_balance,
+ const struct TALER_Amount *denom_risk);
/**
@@ -556,14 +559,16 @@ struct TALER_AUDITORDB_Plugin
* @param cls the @e cls of this struct with the plugin-specific state
* @param session connection to use
* @param denom_pub_hash hash of the denomination public key
* @param[out] denom_balance value of coins outstanding (or issued?) with this denomination key
* @return #GNUNET_OK on success; #GNUNET_NO if no record found, #GNUNET_SYSERR on failure
*/
int
(*get_denomination_balance)(void *cls,
struct TALER_AUDITORDB_Session *session,
const struct GNUNET_HashCode *denom_pub_hash,
- struct TALER_Amount *denom_balance);
+ struct TALER_Amount *denom_balance,
+ struct TALER_Amount *denom_risk);
/**
@@ -522,15 +522,16 @@ struct TALER_AUDITORDB_Plugin
* @param session connection to use
* @param denom_pub_hash hash of the denomination public key
- * @param denom_balance value of coins outstanding (or issued?) with this denomination key
+ * @param denom_balance value of coins outstanding with this denomination key
+ * @param denom_risk value of coins issued with this denomination key
* @return #GNUNET_OK on success; #GNUNET_SYSERR on failure
*/
@@ -540,14 +541,16 @@ struct TALER_AUDITORDB_Plugin
* @param session connection to use
* @param denom_pub_hash hash of the denomination public key
- * @param denom_balance value of coins outstanding (or issued?) with this denomination key
+ * @param denom_balance value of coins outstanding with this denomination key
+ * @param denom_risk value of coins issued with this denomination key
* @return #GNUNET_OK on success; #GNUNET_SYSERR on failure
*/
@@ -556,14 +559,16 @@ struct TALER_AUDITORDB_Plugin
* @param session connection to use
* @param denom_pub_hash hash of the denomination public key
- * @param[out] denom_balance value of coins outstanding (or issued?) with this denomination key
+ * @param[out] denom_balance value of coins outstanding with this denomination key
+ * @param[out] denom_risk value of coins issued with this denomination key
* @return #GNUNET_OK on success; #GNUNET_NO if no record found, #GNUNET_SYSERR on failure
*/